/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Admin **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:46+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Croatian (Croatia) (http://www.transifex.com/tine20/tine20/language/hr_HR/)\nLanguage: hr_HR\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "ImportExportDefinition, ImportExportDefinitions"
: [
  ""
 ,""
 ,""

]
, "Application, Applications"
: [
  "Modul"
 ,"Moduli"
 ,"Modula"

]
, "User, Users"
: [
  "Korisnika"
 ,"Korisnika"
 ,"Korisnika"

]
, "Groups"
: "Grupe"

, "Roles"
: "Uloge"

, "Applications"
: "Moduli"

, "Containers"
: "Spremnici"

, "Shared Tags"
: "Zajedničke oznake"

, "Customfields"
: "Dodatna polja"

, "Computers"
: "Računala"

, "Access Log, Access Logs"
: [
  "Pristupni logovi"
 ,"Pristupna loga"
 ,"Pristupnih logova"

]
, "Log"
: ""

, "Server Information"
: "Informacije o poslužitelju"

, "ActiveSync Devices"
: ""

, "E-mail Accounts"
: ""

, "Import Export Definitions"
: ""

, "Admin"
: "Admin"

, "Refresh"
: "Osvježiti"

, "Disabled"
: ""

, "Feature is disabled by configuration."
: ""

, "Default Addressbook for new contacts and groups"
: "Početni adresar za nove kontakte i grupe"

, "Computer Name"
: "Naziv računala"

, "Config, Configs"
: [
  ""
 ,""
 ,""

]
, "Description"
: "Opis"

, "Name"
: "Naziv"

, "Label"
: "Labela"

, "Value"
: "Vrijednost"

, "Default ({0})"
: ""

, "Yes"
: ""

, "No"
: ""

, "Group Name"
: "Naziv grupe"

, "Visibility"
: "Vidljivost"

, "Display in addressbook"
: "Prikaži u imeniku"

, "Hide from addressbook"
: "Sakrij u imeniku"

, "Saved in Addressbook"
: "Spremljeno u adresar"

, "E-mail"
: ""

, "Only system accounts can be added to Addressbook group"
: ""

, "Group Members"
: "Članovi grupe"

, "Domain is not allowed. Check your SMTP domain configuration."
: "Domena nije dopuštena. Provjerite konfiguraciju Vašeg SMTP servera."

, "Confirm"
: "Potvrdi"

, "Do you really want to delete the selected tags?"
: "Želite li izbrisati označene oznake?"

, "Deleting tag(s)..."
: "Brisanje oznake(a)..."

, "Add Tag"
: "Dodaj Oznaku"

, "Edit Tag"
: "Uredi Oznaku"

, "Delete Tag"
: "Obriši Oznaku"

, "Search:"
: "Pretraži:"

, "Displaying tags {0} - {1} of {2}"
: "Prikaz oznaka {0} - {1} od {2}"

, "No tags to display"
: "Nema oznaka za prikaz"

, "ID"
: "ID"

, "Color"
: "Boja"

, "Usage:&#160;"
: "Iskorišteno:&#160;"

, "Do you really want to delete the selected roles?"
: "Želite li izbrisati označene uloge?"

, "Deleting role(s)..."
: "Brisanje uloge(a)..."

, "Failed"
: "Neuspjelo"

, "Some error occurred while trying to delete the role."
: "Pojavila se greška tijekom brisanja uloge."

, "Add Role"
: "Dodaj Rolu"

, "Edit Role"
: "Uredi Rolu"

, "Delete Role"
: "Obriši Rolu"

, "Displaying roles {0} - {1} of {2}"
: "Prikaz uloga {0} - {1} od {2}"

, "No roles to display"
: "Nema uloga za prikaz"

, "Container Name"
: "Naziv spremnika"

, "Type"
: "Tip"

, "Container Order"
: ""

, "Container, Containers"
: [
  "Spremnik"
 ,"Spremnika"
 ,"Spremnika"

]
, "Model"
: "Model"

, "personal"
: "osobni"

, "shared"
: "dijeljeni"

, "Order"
: "Redoslijed"

, "Container Hierarchy/Name"
: ""

, "Note for Owner"
: "Biljaška za vlasnika"

, "Info"
: ""

, "Please create Resources in Addressbook or CoreData."
: ""

, "Do you really want to delete the selected groups?"
: "Želite li izbrisati označene grupe?"

, "Deleting group(s)..."
: "Brisanje grupe(a)..."

, "Some error occurred while trying to delete the group."
: "Pojavila se greška tijekom brisanja grupe."

, "Add Group"
: "Dodaj grupu"

, "Edit Group"
: "Uredi grupu"

, "Delete Group"
: "Izbriši grupu"

, "Displaying groups {0} - {1} of {2}"
: "Prikaz grupa {0} - {1} od {2}"

, "No groups to display"
: "Nema grupa za prikaz"

, "Account only"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "IP Address"
: "IP Adresa"

, "Login Time"
: "Vrijeme prijave"

, "Logout Time"
: "Vrijeme odjave"

, "Client Type"
: "Tip klijenta"

, "Session ID"
: "ID sesije"

, "Login Name"
: "Korisničko ime"

, "Result"
: "Rezultat"

, "User Agent"
: ""

, "user blocked"
: "korisnik blokiran"

, "password expired"
: "lozinka istekla"

, "user disabled"
: "korisnik onemogućen"

, "invalid password"
: "Neispravna zaporka"

, "ambiguous username"
: "nejasno korisničko ime"

, "user not found"
: "korisnik nije pronađen"

, "failure"
: "neuspješno"

, "success"
: "uspješno"

, "Customfield, Customfields"
: [
  "Dodatno polje"
 ,"Dodatna polja"
 ,"Dodatnih polja"

]
, "This custom field is still in use!"
: ""

, "Are you sure you want to delete them?"
: ""

, "Errors"
: "Greške"

, "Please configure store for this field type"
: "Molimo Vas postavite spremanje za ovo polje"

, "Record Class"
: "Zapisnik klase"

, "Given record class not found"
: "Zadni zapisnik klase nije pronađen"

, "Cancel"
: "Odustani"

, "OK"
: "U redu"

, "Configure store"
: "Postavite spremanje"

, "Custom field definition"
: "Definicija Dodatnog polja"

, "Text"
: "Tekst"

, "Textarea"
: ""

, "Number"
: "Broj"

, "Date"
: "Datum"

, "DateTime"
: "Datum i vrijeme"

, "Time"
: "Vrijeme"

, "Boolean"
: "Boolean"

, "Search Combo"
: "Polje za pretragu"

, "Key Field"
: "Polje vrijednosti"

, "Record"
: "Zapis"

, "Record List"
: ""

, "Length"
: "Dužina"

, "Required"
: "Obavezno"

, "Custom field additional properties"
: "Dodatne opcije Dodatnih polja"

, "Tab Panel"
: ""

, "Group, Groups"
: [
  "Grupa"
 ,"Grupe"
 ,"Grupa"

]
, "Key"
: ""

, "Customfield already exists. Please choose another name."
: "Dodatno polje već postoji. Molimo odaberite drugo ime."

, "Enable Account"
: "Omogući račun"

, "Disable Account"
: "Onemogući račun"

, "Reset Password"
: "Resetiraj lozinku"

, "Status"
: "Status"

, "Display name"
: "Prikaz imena"

, "Login name"
: "Korisničko ime"

, "Last name"
: "Prezime"

, "First name"
: "Ime"

, "E-mail usage"
: ""

, "Filesystem usage"
: ""

, "OpenID"
: "OpenID"

, "Last login at"
: "Zadnja prijava"

, "Last login from"
: "Zadnja prijava od"

, "Password Must Change"
: "Potrebna promjena zaporke"

, "Password changed"
: "Zaporka je promijenjena"

, "Expires"
: "Ističe"

, "Set new password"
: "Postavi novu zaporku"

, "Please enter the new password:"
: "Molimo Vas da unesete novu zaporku:"

, "Users"
: "Korisnici"

, "Samba User, Samba Users"
: [
  "Samba korisnik"
 ,"Samba korisnika"
 ,"Samba korisnika"

]
, "Email User, Email Users"
: [
  "E-mail korisnik"
 ,"E-mail korisnika"
 ,"E-mail korisnika"

]
, "Special characters are not allowed in login name."
: ""

, "Passwords do not match!"
: "Zaporke nisu jednake!"

, "Passwords match!"
: "Lozinke su iste!"

, "Primary group"
: "Primarna grupa"

, "Unix"
: "Unix"

, "Home Directory"
: "Početna mapa"

, "Login Shell"
: "Login Shell"

, "Windows"
: "Windows"

, "Home Drive"
: "Početni disk"

, "never logged in"
: "Nikada prijavljen"

, "Home Path"
: "Početna lokacija"

, "never logged off"
: "Nikada odjavljen"

, "Profile Path"
: "Lokacija profila"

, "Password Last Set"
: "Zadnja postavljena zaporka"

, "never"
: "nikada"

, "Logon Script"
: "Skripta prijave"

, "Password Can Change"
: "Dozvoljena promjena zaporke"

, "not set"
: "nije postavljeno"

, "Kick Off Time"
: "Vrijeme početka"

, "Filesystem Quota"
: ""

, "Quota"
: "Ograničenje"

, "no quota set"
: "ograničenje nije postavljeno"

, "Current Filesystem usage"
: ""

, "IMAP Quota"
: ""

, "Current Mailbox size"
: "Trenutna veličina Sandučića"

, "Sieve Quota"
: ""

, "Current Sieve size"
: "Trenutna veličina Sieve"

, "Information"
: "Informacija"

, "Last Login"
: "Zadnja prijava"

, "Forward Only"
: "Samo proslijedi"

, "E-mail Alias"
: ""

, "Add an alias address..."
: "Dodaj alias adresu..."

, "This alias can be used for sending e-mails."
: ""

, "Domain not allowed"
: "Domena nije dozvoljena"

, "The domain {0} of the alias {1} you tried to add is neither configured as primary domain nor set as a secondary domain in the setup. Please add this domain to the secondary domains in SMTP setup or use another domain which is configured already."
: ""

, "Forwarding to self"
: "Prosjediti na sebe"

, "You are not allowed to set a forwarding e-mail address that is identical to the users primary e-mail or one of his aliases."
: ""

, "E-mail Forward"
: ""

, "Add a forwarding address..."
: ""

, "Password confirmation"
: "Potvrda zaporke"

, "Repeat password"
: "Ponovite zaporku"

, "Ok"
: "Spremi"

, "Account"
: "Račun"

, "Password"
: "Zaporka"

, "Multi Factor Authentication Config"
: ""

, "enabled"
: "Omogućeno"

, "disabled"
: "Onemogućeno"

, "expired"
: "Isteklo"

, "blocked"
: "Blokiran"

, "Invalid Status"
: "Status ne postoji"

, "Blocked status is only valid if the user tried to login with a wrong password to often. It is not possible to set this status here."
: "Status Blokiran je moguć samo ukoliko se korisnik pokuša prijaviti sa krivom lozinkom prevelik broj puta. Taj status nije moguće ovdje postaviti."

, "don't know"
: "ne zna"

, "Password set"
: "Zaporka postavljena"

, "User groups"
: "Korisničke grupe"

, "User roles"
: "Korisničke role"

, "Fileserver"
: "Fileserver"

, "Filesystem"
: ""

, "IMAP"
: "IMAP"

, "SMTP"
: "SMTP"

, "Computer, Computers"
: [
  "Računalo"
 ,"Računala"
 ,"Računala"

]
, "Please wait"
: "Molimo pričekajte"

, "Updating Memberships"
: "Ažuriranje članova"

, "Could not save role."
: "Nije moguće spremiti ulogu."

, "Please fix the errors noted."
: "Molimo Vas da ispravite zabilježene greške."

, "Deleting role..."
: "Brisanje uloge..."

, "Rights"
: "Prava"

, "Members"
: "Članovi"

, "Role Name"
: "Naziv uloge"

, "Transferring {0}..."
: "Prijenos {0}..."

, "Role"
: "Uloga"

, "Add New Role"
: "Dodaj novu ulogu"

, "Edit Role \"{0}\""
: "Uredi Ulogu \"{0}\""

, "Configs"
: ""

, "Size"
: ""

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Quota Usage"
: ""

, "Updating Tag"
: "Ažuriranje oznake"

, "Could not save tag ({0})"
: ""

, "Allowed Contexts"
: "Dozvoljena značenja"

, "Context"
: "Značenje"

, "Account Rights"
: "Prava korisničkog računa"

, "View"
: "Pregled"

, "Use"
: "Korištenje"

, "Tag Name"
: "Naziv oznake"

, "Tag"
: "Oznaka"

, "Add New Tag"
: "Dodaj novu oznaku"

, "Edit Tag \"{0}\""
: "Uredi Oznaku \"{0}\""

, "Enable Application"
: "Omogući Modul"

, "Disable Application"
: "Onemogući Modul"

, "Settings"
: "Postavke"

, "{0} Settings"
: "{0} Postavke"

, "Enabled"
: ""

, "Unknown status ({0})"
: ""

, "Displaying application {0} - {1} of {2}"
: "Prikaz modula {0} - {1} od {2}"

, "No applications to display"
: "Nema modula za prikaz"

, "Version"
: "Verzija"

, "Default password must change for new user settings"
: ""

, "Default IMAP user settings"
: "Glavne IMAP korisničke postavke"

, "Enabled Features"
: ""

, "Enabled Features in Admin Application."
: ""

, "Prevent special chars in login name"
: ""

, "Force retype of new password in user edit dialog"
: ""

, "Your container has been changed"
: "Vaš spremnik je izmijenjen"

, "Your container has been changed by %1$s %2$sNote: %3$s"
: "Vaš spremnik je izmijenje id %1$s %2$s. Bilješka: %3$s"

, "Password is needed for system account creation"
: ""

, "Notifications"
: ""

, "Manage access log"
: ""

, "Delete access log entries."
: ""

, "Manage accounts"
: ""

, "Add and edit users and groups, add group members, change user passwords."
: ""

, "Manage e-mail accounts"
: ""

, "Add and edit shared and personal e-mail accounts."
: ""

, "Manage applications"
: ""

, "Enable and disable applications, edit application settings."
: ""

, "Manage roles"
: ""

, "Add and edit roles, add new members to roles, add application rights to roles."
: ""

, "Manage shared tags"
: ""

, "Add, delete and edit shared tags."
: ""

, "Manage computers"
: ""

, "Add, delete and edit (samba) computers."
: ""

, "Manage containers"
: ""

, "Add, delete and edit containers and manage container grants."
: ""

, "Manage customfields"
: ""

, "Add and edit customfields."
: ""

, "Manage import and export definitions"
: ""

, "Add and edit import and export definitions"
: ""

, "View access log"
: ""

, "View access log list."
: ""

, "View accounts"
: ""

, "View accounts list and details."
: ""

, "View e-mail accounts"
: ""

, "View shared and personal e-mail accounts."
: ""

, "View applications"
: ""

, "View applications list and details."
: ""

, "View roles"
: ""

, "View roles list and details."
: ""

, "View shared tags"
: ""

, "View shared tags list and details."
: ""

, "View computers"
: ""

, "View computers list and details."
: ""

, "View containers"
: ""

, "View personal and shared containers."
: ""

, "View customfields"
: ""

, "View customfields list."
: ""

, "View serverinfo"
: ""

, "View serverinfo list."
: ""

, "View quota usage"
: ""

, "View quota usage."
: ""

, "view ImportExportDefinitions"
: ""






































, "ImportExportDefinition"
: ""

, "Application"
: "Modul"

, "User"
: "Korisnika"

, "Access Log"
: "Pristupni logovi"

, "Config"
: ""

, "Container"
: "Spremnik"

, "Customfield"
: "Dodatno polje"

, "Group"
: "Grupa"

, "Samba User"
: "Samba korisnik"

, "Email User"
: "E-mail korisnik"

, "Computer"
: "Računalo"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
